#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open("README.md") as readme_file:
    readme = readme_file.read()

with open("CHANGELOG.md") as history_file:
    history = history_file.read()

requirements = [
    "numpy",
    "pygame",
    "scipy",
    "pytest>=3",
    "pyyaml",
    "pygame-gui",
    "fastapi",
    "uvicorn",
    "websockets",
    "requests",
    "platformdirs",
]

test_requirements = [
    "pytest>=3",
]

setup(
    author="Annika Österdiekhoff, Dominik Battefeld, Fabian Heinrich, Florian Schröder",
    author_email="florian.schroeder@uni-bielefeld.de",
    python_requires=">=3.10",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.10",
    ],
    description="The real-time overcooked simulation for a cognitive cooperative system",
    entry_points={
        "console_scripts": ["overcooked-sim = overcooked_simulator.__main__:main"]
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + "\n\n" + history,
    include_package_data=True,
    keywords=["overcooked_simulator"],
    name="overcooked_simulator",
    packages=find_packages(include=["overcooked_simulator", "overcooked_simulator.*"]),
    test_suite="tests",
    tests_require=test_requirements,
    url="https://gitlab.ub.uni-bielefeld.de/scs/cocosy/overcooked-simulator",
    version="0.1.0",
    zip_safe=False,
)
